#include "stdafx.h"
#include "listView.h"


/* *****************************************************************************
***************************************************************************** */

CListView::CListView(HINSTANCE hInstance,HWND hwndMaster,int x,int y,int dx,int dy)
{
	m_hwndMaster = hwndMaster;
	m_hInst = hInstance;
	m_nbColumn = 0;
	m_line = 0;
	m_column = 0;
	m_lineSelected = 0;
	m_columnSelected = 0;
	InitCommonControls();
	
	DWORD dwStyle = WS_TABSTOP | WS_CHILD | WS_BORDER | WS_VISIBLE |LVS_AUTOARRANGE |LVS_REPORT | LVS_OWNERDATA;
	m_hwndListView = CreateWindowEx( 
		WS_EX_CLIENTEDGE,WC_LISTVIEW,"",dwStyle,
		x,y,dx,dy,
		m_hwndMaster,NULL,m_hInst,NULL);

	if(m_hwndListView) 
	{
		ListView_DeleteAllItems(m_hwndListView);  
	}
}


/* *****************************************************************************
***************************************************************************** */

CListView::CListView (HWND hwndListView)
{
	m_hwndListView= hwndListView;
	m_hwndMaster = 0;
	m_hInst = 0;
	m_nbColumn = 0;
	m_line = 0;
	m_column = 0;
	m_lineSelected = 0;
	m_columnSelected = 0;
}


/* *****************************************************************************
***************************************************************************** */

CListView::~CListView()
{
	DestroyWindow(m_hwndListView);
}


/* *****************************************************************************
***************************************************************************** */

BOOL CListView::AddColumn (char *nameHead,int size)
{
	LV_COLUMN   lvColumn;

	//initialize the columns
	lvColumn.mask = LVCF_FMT | LVCF_WIDTH | LVCF_TEXT | LVCF_SUBITEM;
	lvColumn.fmt = LVCFMT_LEFT;
	lvColumn.cx = size;
	lvColumn.pszText = nameHead;
	ListView_InsertColumn(m_hwndListView, m_nbColumn++, &lvColumn);
	return TRUE;
}


/* *****************************************************************************
***************************************************************************** */

void CListView::SetNbCount(int nbCountx)
{
	m_nbCount = nbCountx;
	ListView_SetItemCount(m_hwndListView, m_nbCount);
}

void CListView::IncCount ()
{
	SetNbCount(m_nbCount+1);
}

void CListView::DecCount ()
{
	SetNbCount(m_nbCount-1);
}


/* *************************************************************************
	interprete le message WM_NOTIFY de la callback mere du ListCtrl:

	getDispInfo     iItem iSubItem; 
	itemChanged		iItem

	char temp[128];
	CListView list;

	ENotify res = list.Notify(lParam);
	switch (res)
	{
		case getDispInfo:
			sprintf(temp, "On demande les infos concernant: ligne %d - colone %d", list.GetLine , list.GetColumn);
			list.SetItemText(temp);
			break;

		case itemChanged:
			sprintf(temp,"ligne: %d colone %d",list.GetLineSelected ,list.GetColumnSelected);
			MessageBox(NULL,temp,"Nouvelle selection:",0);
			break;
	}
************************************************************************* */


ENotify CListView::Notify (LPARAM lParam)
{
	LPNMHDR lpnmh = (LPNMHDR) lParam;
	if (lpnmh->hwndFrom != m_hwndListView) return nothing;

	switch (lpnmh->code)
	{
		case LVN_GETDISPINFO:
			{
				LV_DISPINFO *lpdi = (LV_DISPINFO *)lParam;
				m_line = lpdi->item.iItem;
				m_column = lpdi->item.iSubItem;
				m_itemText = lpdi->item.pszText;
				return lpdi->item.mask & LVIF_TEXT ? getDispInfo : nothing;
			}
			break;

		case LVN_ITEMCHANGED:
			{
				LPNMLISTVIEW lpnmlist = (LPNMLISTVIEW ) lParam;
				m_lineSelected =  lpnmlist->iItem;
				m_columnSelected = lpnmlist->iSubItem;
				return itemChanged;
			}
			break;
	}
	return nothing;
}


/* *************************************************************************
************************************************************************* */

void CListView::Refresh ()
{
	InvalidateRect(m_hwndListView,NULL,TRUE);
}


/* *************************************************************************
************************************************************************* */

int	CListView::GetLine()
{
	return m_line;
}


/* *************************************************************************
************************************************************************* */

int	CListView::GetColumn()
{
	return m_column;
}


/* *************************************************************************
************************************************************************* */

int	CListView::GetLineSelected()
{
	return m_lineSelected;
}


/* *************************************************************************
************************************************************************* */

int	CListView::GetColumnSelected()
{
	return m_columnSelected;
}


/* *************************************************************************
************************************************************************* */

void CListView::SetItemText(char *text)
{
	if (text) strcpy (m_itemText,text);
}


/* *************************************************************************
************************************************************************* */

